==> base-domain-0.0.3-20161208.023505-16-sources.jar: com/thebeastshop/scm/vo/lottery/LotteryActivityAwardEditVO.java <==
package com.thebeastshop.scm.vo.lottery;

import pers.richard.ormybatis.domain.core.AbstractDomain;

/**
 * 抽奖活动编辑VO
 * @author donghui
 */
public class LotteryActivityAwardEditVO extends AbstractDomain {
	private Integer awardId;
	private String awardName;
	private Integer awardQuantity;
	private Integer awardWinQuantity;
	private Integer awardOdds;
	private String awardContent;

	private Integer prizeId;
	private String prizeType;
	private Integer prizeTypeNum;
	
	public LotteryActivityAwardEditVO(){}
	
	public Integer getAwardId() {
		return awardId;
	}

	public void setAwardId(Integer awardId) {
		this.awardId = awardId;
	}

	public String getAwardName() {
		return awardName;
	}
	public Integer getAwardWinQuantity() {
		return awardWinQuantity;
	}

	public void setAwardWinQuantity(Integer awardWinQuantity) {
		this.awardWinQuantity = awardWinQuantity;
	}
	public void setAwardName(String awardName) {
		this.awardName = awardName;
	}

	public Integer getAwardQuantity() {
		return awardQuantity;
	}

	public void setAwardQuantity(Integer awardQuantity) {
		this.awardQuantity = awardQuantity;
	}

	public Integer getAwardOdds() {
		return awardOdds;
	}

	public void setAwardOdds(Integer awardOdds) {
		this.awardOdds = awardOdds;
	}

	public String getAwardContent() {
		return awardContent;
	}

	public void setAwardContent(String awardContent) {
		this.awardContent = awardContent;
	}
	public Integer getPrizeId() {
		return prizeId;
	}
	public void setPrizeId(Integer prizeId) {
		this.prizeId = prizeId;
	}
	public String getPrizeType() {
		return prizeType;
	}

	public void setPrizeType(String prizeType) {
		this.prizeType = prizeType;
	}
	public Integer getPrizeTypeNum() {
		return prizeTypeNum;
	}
	public void setPrizeTypeNum(Integer prizeTypeNum) {
		this.prizeTypeNum = prizeTypeNum;
	}

}

==> base-domain-0.0.3-20161223.061051-46-sources.jar: com/thebeastshop/scm/vo/lottery/LotteryActivityAwardEditVO.java <==
package com.thebeastshop.scm.vo.lottery;

import pers.richard.ormybatis.domain.core.AbstractDomain;

/**
 * 抽奖活动编辑VO
 * @author donghui
 */
public class LotteryActivityAwardEditVO extends AbstractDomain {
	private Integer awardId;
	private String awardName;
	private Integer awardQuantity;
	private Integer awardWinQuantity;
	private Integer awardOdds;
	private String awardContent;

	private Integer prizeId;
	private String prizeType;
	private String prizeTypeNum;
	
	public LotteryActivityAwardEditVO(){}
	
	public Integer getAwardId() {
		return awardId;
	}

	public void setAwardId(Integer awardId) {
		this.awardId = awardId;
	}

	public String getAwardName() {
		return awardName;
	}
	public Integer getAwardWinQuantity() {
		return awardWinQuantity;
	}

	public void setAwardWinQuantity(Integer awardWinQuantity) {
		this.awardWinQuantity = awardWinQuantity;
	}
	public void setAwardName(String awardName) {
		this.awardName = awardName;
	}

	public Integer getAwardQuantity() {
		return awardQuantity;
	}

	public void setAwardQuantity(Integer awardQuantity) {
		this.awardQuantity = awardQuantity;
	}

	public Integer getAwardOdds() {
		return awardOdds;
	}

	public void setAwardOdds(Integer awardOdds) {
		this.awardOdds = awardOdds;
	}

	public String getAwardContent() {
		return awardContent;
	}

	public void setAwardContent(String awardContent) {
		this.awardContent = awardContent;
	}
	public Integer getPrizeId() {
		return prizeId;
	}
	public void setPrizeId(Integer prizeId) {
		this.prizeId = prizeId;
	}
	public String getPrizeType() {
		return prizeType;
	}

	public void setPrizeType(String prizeType) {
		this.prizeType = prizeType;
	}
	public String getPrizeTypeNum() {
		return prizeTypeNum;
	}
	public void setPrizeTypeNum(String prizeTypeNum) {
		this.prizeTypeNum = prizeTypeNum;
	}

}
